@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IDirectory_VERSION = "4.1.56794"
+IDirectory_VERSION = "4.1.56799"
 
 class IDirectory(BaseEndpoint):
     def __init__(self, apiKey, url ,domain ):
@@ -75,6 +75,20 @@ class IDirectory(BaseEndpoint):
         from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
         from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
         return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
+    def getByRoles (self, roles ):
+        postUri = "/_byroles";
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.STRING).encode(roles)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirectory_VERSION}, data = __encoded__);
+        from netbluemind.directory.api.DirEntry import DirEntry
+        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__DirEntrySerDer__())), response)
     def search (self, query ):
         postUri = "/_search";
         __data__ = None
